Class: Aws::ManagedGrafana::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ManagedGrafana::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-managedgrafana/client.rb,
sig/client.rbs
Overview
An API client for ManagedGrafana. To construct a client, you need to configure a :region and :credentials.
client = Aws::ManagedGrafana::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateLicenseResponseSuccess, _CreateWorkspaceApiKeyResponseSuccess, _CreateWorkspaceResponseSuccess, _CreateWorkspaceServiceAccountResponseSuccess, _CreateWorkspaceServiceAccountTokenResponseSuccess, _DeleteWorkspaceApiKeyResponseSuccess, _DeleteWorkspaceResponseSuccess, _DeleteWorkspaceServiceAccountResponseSuccess, _DeleteWorkspaceServiceAccountTokenResponseSuccess, _DescribeWorkspaceAuthenticationResponseSuccess, _DescribeWorkspaceConfigurationResponseSuccess, _DescribeWorkspaceResponseSuccess, _DisassociateLicenseResponseSuccess, _ListPermissionsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListVersionsResponseSuccess, _ListWorkspaceServiceAccountTokensResponseSuccess, _ListWorkspaceServiceAccountsResponseSuccess, _ListWorkspacesResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdatePermissionsResponseSuccess, _UpdateWorkspaceAuthenticationResponseSuccess, _UpdateWorkspaceConfigurationResponseSuccess, _UpdateWorkspaceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_license(params = {}) ⇒ Types::AssociateLicenseResponse
Assigns a Grafana Enterprise license to a workspace.
-
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workspace.
-
#create_workspace_api_key(params = {}) ⇒ Types::CreateWorkspaceApiKeyResponse
Creates a Grafana API key for the workspace.
-
#create_workspace_service_account(params = {}) ⇒ Types::CreateWorkspaceServiceAccountResponse
Creates a service account for the workspace.
-
#create_workspace_service_account_token(params = {}) ⇒ Types::CreateWorkspaceServiceAccountTokenResponse
Creates a token that can be used to authenticate and authorize Grafana HTTP API operations for the given [workspace service account][1].
-
#delete_workspace(params = {}) ⇒ Types::DeleteWorkspaceResponse
Deletes an Amazon Managed Grafana workspace.
-
#delete_workspace_api_key(params = {}) ⇒ Types::DeleteWorkspaceApiKeyResponse
Deletes a Grafana API key for the workspace.
-
#delete_workspace_service_account(params = {}) ⇒ Types::DeleteWorkspaceServiceAccountResponse
Deletes a workspace service account from the workspace.
-
#delete_workspace_service_account_token(params = {}) ⇒ Types::DeleteWorkspaceServiceAccountTokenResponse
Deletes a token for the workspace service account.
-
#describe_workspace(params = {}) ⇒ Types::DescribeWorkspaceResponse
Displays information about one Amazon Managed Grafana workspace.
-
#describe_workspace_authentication(params = {}) ⇒ Types::DescribeWorkspaceAuthenticationResponse
Displays information about the authentication methods used in one Amazon Managed Grafana workspace.
-
#describe_workspace_configuration(params = {}) ⇒ Types::DescribeWorkspaceConfigurationResponse
Gets the current configuration string for the given workspace.
-
#disassociate_license(params = {}) ⇒ Types::DisassociateLicenseResponse
Removes the Grafana Enterprise license from a workspace.
-
#list_permissions(params = {}) ⇒ Types::ListPermissionsResponse
Lists the users and groups who have the Grafana
AdminandEditorroles in this workspace. -
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
The
ListTagsForResourceoperation returns the tags that are associated with the Amazon Managed Service for Grafana resource specified by theresourceArn. -
#list_versions(params = {}) ⇒ Types::ListVersionsResponse
Lists available versions of Grafana.
-
#list_workspace_service_account_tokens(params = {}) ⇒ Types::ListWorkspaceServiceAccountTokensResponse
Returns a list of tokens for a workspace service account.
-
#list_workspace_service_accounts(params = {}) ⇒ Types::ListWorkspaceServiceAccountsResponse
Returns a list of service accounts for a workspace.
-
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Returns a list of Amazon Managed Grafana workspaces in the account, with some information about each workspace.
-
#tag_resource(params = {}) ⇒ Struct
The
TagResourceoperation associates tags with an Amazon Managed Grafana resource. -
#untag_resource(params = {}) ⇒ Struct
The
UntagResourceoperation removes the association of the tag with the Amazon Managed Grafana resource. -
#update_permissions(params = {}) ⇒ Types::UpdatePermissionsResponse
Updates which users in a workspace have the Grafana
AdminorEditorroles. -
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Modifies an existing Amazon Managed Grafana workspace.
-
#update_workspace_authentication(params = {}) ⇒ Types::UpdateWorkspaceAuthenticationResponse
Use this operation to define the identity provider (IdP) that this workspace authenticates users from, using SAML.
-
#update_workspace_configuration(params = {}) ⇒ Struct
Updates the configuration string for the given workspace.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-managedgrafana/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2249 2250 2251 |
# File 'lib/aws-sdk-managedgrafana/client.rb', line 2249 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2252 2253 2254 |
# File 'lib/aws-sdk-managedgrafana/client.rb', line 2252 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_license(params = {}) ⇒ Types::AssociateLicenseResponse
Assigns a Grafana Enterprise license to a workspace. To upgrade, you
must use ENTERPRISE for the licenseType, and pass in a valid
Grafana Labs token for the grafanaToken. Upgrading to Grafana
Enterprise incurs additional fees. For more information, see Upgrade
a workspace to Grafana Enterprise.
86 |
# File 'sig/client.rbs', line 86
def associate_license: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 |
# File 'lib/aws-sdk-managedgrafana/client.rb', line 2222 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ManagedGrafana') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-managedgrafana' context[:gem_version] = '1.66.0' Seahorse::Client::Request.new(handlers, context) end |
#create_workspace(params = {}) ⇒ Types::CreateWorkspaceResponse
Creates a workspace. In a workspace, you can create Grafana dashboards and visualizations to analyze your metrics, logs, and traces. You don't have to build, package, or deploy any hardware to run the Grafana server.
Don't use CreateWorkspace to modify an existing workspace. Instead,
use UpdateWorkspace.
98 |
# File 'sig/client.rbs', line 98
def create_workspace: (
|
#create_workspace_api_key(params = {}) ⇒ Types::CreateWorkspaceApiKeyResponse
Creates a Grafana API key for the workspace. This key can be used to authenticate requests sent to the workspace's HTTP API. See https://docs.aws.amazon.com/grafana/latest/userguide/Using-Grafana-APIs.html for available APIs and example requests.
134 |
# File 'sig/client.rbs', line 134
def create_workspace_api_key: (
|
#create_workspace_service_account(params = {}) ⇒ Types::CreateWorkspaceServiceAccountResponse
Creates a service account for the workspace. A service account can be
used to call Grafana HTTP APIs, and run automated workloads. After
creating the service account with the correct GrafanaRole for your
use case, use CreateWorkspaceServiceAccountToken to create a token
that can be used to authenticate and authorize Grafana HTTP API calls.
You can only create service accounts for workspaces that are compatible with Grafana version 9 and above.
For more information about the Grafana HTTP APIs, see Using Grafana HTTP APIs in the Amazon Managed Grafana User Guide.
150 |
# File 'sig/client.rbs', line 150
def create_workspace_service_account: (
|
#create_workspace_service_account_token(params = {}) ⇒ Types::CreateWorkspaceServiceAccountTokenResponse
Creates a token that can be used to authenticate and authorize Grafana HTTP API operations for the given workspace service account. The service account acts as a user for the API operations, and defines the permissions that are used by the API.
When you create the service account token, you will receive a key that is used when calling Grafana APIs. Do not lose this key, as it will not be retrievable again.
If you do lose the key, you can delete the token and recreate it to receive a new key. This will disable the initial key.
Service accounts are only available for workspaces that are compatible with Grafana version 9 and above.
164 |
# File 'sig/client.rbs', line 164
def create_workspace_service_account_token: (
|
#delete_workspace(params = {}) ⇒ Types::DeleteWorkspaceResponse
Deletes an Amazon Managed Grafana workspace.
177 |
# File 'sig/client.rbs', line 177
def delete_workspace: (
|
#delete_workspace_api_key(params = {}) ⇒ Types::DeleteWorkspaceApiKeyResponse
Deletes a Grafana API key for the workspace.
188 |
# File 'sig/client.rbs', line 188
def delete_workspace_api_key: (
|
#delete_workspace_service_account(params = {}) ⇒ Types::DeleteWorkspaceServiceAccountResponse
Deletes a workspace service account from the workspace.
This will delete any tokens created for the service account, as well. If the tokens are currently in use, the will fail to authenticate / authorize after they are deleted.
Service accounts are only available for workspaces that are compatible with Grafana version 9 and above.
200 |
# File 'sig/client.rbs', line 200
def delete_workspace_service_account: (
|
#delete_workspace_service_account_token(params = {}) ⇒ Types::DeleteWorkspaceServiceAccountTokenResponse
Deletes a token for the workspace service account.
This will disable the key associated with the token. If any automation is currently using the key, it will no longer be authenticated or authorized to perform actions with the Grafana HTTP APIs.
Service accounts are only available for workspaces that are compatible with Grafana version 9 and above.
213 |
# File 'sig/client.rbs', line 213
def delete_workspace_service_account_token: (
|
#describe_workspace(params = {}) ⇒ Types::DescribeWorkspaceResponse
Displays information about one Amazon Managed Grafana workspace.
225 |
# File 'sig/client.rbs', line 225
def describe_workspace: (
|
#describe_workspace_authentication(params = {}) ⇒ Types::DescribeWorkspaceAuthenticationResponse
Displays information about the authentication methods used in one Amazon Managed Grafana workspace.
235 |
# File 'sig/client.rbs', line 235
def describe_workspace_authentication: (
|
#describe_workspace_configuration(params = {}) ⇒ Types::DescribeWorkspaceConfigurationResponse
Gets the current configuration string for the given workspace.
246 |
# File 'sig/client.rbs', line 246
def describe_workspace_configuration: (
|
#disassociate_license(params = {}) ⇒ Types::DisassociateLicenseResponse
Removes the Grafana Enterprise license from a workspace.
256 |
# File 'sig/client.rbs', line 256
def disassociate_license: (
|
#list_permissions(params = {}) ⇒ Types::ListPermissionsResponse
Lists the users and groups who have the Grafana Admin and Editor
roles in this workspace. If you use this operation without specifying
userId or groupId, the operation returns the roles of all users
and groups. If you specify a userId or a groupId, only the roles
for that user or group are returned. If you do this, you can specify
only one userId or one groupId.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
268 |
# File 'sig/client.rbs', line 268
def list_permissions: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
The ListTagsForResource operation returns the tags that are
associated with the Amazon Managed Service for Grafana resource
specified by the resourceArn. Currently, the only resource that can
be tagged is a workspace.
283 |
# File 'sig/client.rbs', line 283
def list_tags_for_resource: (
|
#list_versions(params = {}) ⇒ Types::ListVersionsResponse
Lists available versions of Grafana. These are available when calling
CreateWorkspace. Optionally, include a workspace to list the
versions to which it can be upgraded.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
294 |
# File 'sig/client.rbs', line 294
def list_versions: (
|
#list_workspace_service_account_tokens(params = {}) ⇒ Types::ListWorkspaceServiceAccountTokensResponse
Returns a list of tokens for a workspace service account.
Service accounts are only available for workspaces that are compatible with Grafana version 9 and above.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
309 |
# File 'sig/client.rbs', line 309
def list_workspace_service_account_tokens: (
|
#list_workspace_service_accounts(params = {}) ⇒ Types::ListWorkspaceServiceAccountsResponse
Returns a list of service accounts for a workspace.
Service accounts are only available for workspaces that are compatible with Grafana version 9 and above.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
324 |
# File 'sig/client.rbs', line 324
def list_workspace_service_accounts: (
|
#list_workspaces(params = {}) ⇒ Types::ListWorkspacesResponse
Returns a list of Amazon Managed Grafana workspaces in the account, with some information about each workspace. For more complete information about one workspace, use DescribeWorkspace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
337 |
# File 'sig/client.rbs', line 337
def list_workspaces: (
|
#tag_resource(params = {}) ⇒ Struct
The TagResource operation associates tags with an Amazon Managed
Grafana resource. Currently, the only resource that can be tagged is
workspaces.
If you specify a new tag key for the resource, this tag is appended to the list of tags associated with the resource. If you specify a tag key that is already associated with the resource, the new tag value that you specify replaces the previous value for that tag.
347 |
# File 'sig/client.rbs', line 347
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
The UntagResource operation removes the association of the tag with
the Amazon Managed Grafana resource.
357 |
# File 'sig/client.rbs', line 357
def untag_resource: (
|
#update_permissions(params = {}) ⇒ Types::UpdatePermissionsResponse
Updates which users in a workspace have the Grafana Admin or
Editor roles.
368 |
# File 'sig/client.rbs', line 368
def update_permissions: (
|
#update_workspace(params = {}) ⇒ Types::UpdateWorkspaceResponse
Modifies an existing Amazon Managed Grafana workspace. If you use this operation and omit any optional parameters, the existing values of those parameters are not changed.
To modify the user authentication methods that the workspace uses, such as SAML or IAM Identity Center, use UpdateWorkspaceAuthentication.
To modify which users in the workspace have the Admin and Editor
Grafana roles, use UpdatePermissions.
390 |
# File 'sig/client.rbs', line 390
def update_workspace: (
|
#update_workspace_authentication(params = {}) ⇒ Types::UpdateWorkspaceAuthenticationResponse
Use this operation to define the identity provider (IdP) that this
workspace authenticates users from, using SAML. You can also map SAML
assertion attributes to workspace user information and define which
groups in the assertion attribute are to have the Admin and Editor
roles in the workspace.
421 |
# File 'sig/client.rbs', line 421
def update_workspace_authentication: (
|
#update_workspace_configuration(params = {}) ⇒ Struct
Updates the configuration string for the given workspace
451 |
# File 'sig/client.rbs', line 451
def update_workspace_configuration: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2242 2243 2244 |
# File 'lib/aws-sdk-managedgrafana/client.rb', line 2242 def waiter_names [] end |