Class: Aws::ManagedGrafana::Types::CreateWorkspaceServiceAccountRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-managedgrafana/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#grafana_roleString

The permission level to use for this service account.

For more information about the roles and the permissions each has, see User roles in the Amazon Managed Grafana User Guide.

Returns:

  • (String)


491
492
493
494
495
496
497
# File 'lib/aws-sdk-managedgrafana/types.rb', line 491

class CreateWorkspaceServiceAccountRequest < Struct.new(
  :name,
  :grafana_role,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A name for the service account. The name must be unique within the workspace, as it determines the ID associated with the service account.

Returns:

  • (String)


491
492
493
494
495
496
497
# File 'lib/aws-sdk-managedgrafana/types.rb', line 491

class CreateWorkspaceServiceAccountRequest < Struct.new(
  :name,
  :grafana_role,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace within which to create the service account.

Returns:

  • (String)


491
492
493
494
495
496
497
# File 'lib/aws-sdk-managedgrafana/types.rb', line 491

class CreateWorkspaceServiceAccountRequest < Struct.new(
  :name,
  :grafana_role,
  :workspace_id)
  SENSITIVE = []
  include Aws::Structure
end