Class: Aws::ManagedGrafana::Types::CreateWorkspaceServiceAccountResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ManagedGrafana::Types::CreateWorkspaceServiceAccountResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-managedgrafana/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#grafana_role ⇒ String
The permission level given to the service account.
-
#id ⇒ String
The ID of the service account.
-
#name ⇒ String
The name of the service account.
-
#workspace_id ⇒ String
The workspace with which the service account is associated.
Instance Attribute Details
#grafana_role ⇒ String
The permission level given to the service account.
506 507 508 509 510 511 512 513 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 506 class CreateWorkspaceServiceAccountResponse < Struct.new( :id, :name, :grafana_role, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the service account.
506 507 508 509 510 511 512 513 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 506 class CreateWorkspaceServiceAccountResponse < Struct.new( :id, :name, :grafana_role, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the service account.
506 507 508 509 510 511 512 513 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 506 class CreateWorkspaceServiceAccountResponse < Struct.new( :id, :name, :grafana_role, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The workspace with which the service account is associated.
506 507 508 509 510 511 512 513 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 506 class CreateWorkspaceServiceAccountResponse < Struct.new( :id, :name, :grafana_role, :workspace_id) SENSITIVE = [] include Aws::Structure end |