Class: Aws::ManagedGrafana::Types::CreateWorkspaceServiceAccountTokenRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ManagedGrafana::Types::CreateWorkspaceServiceAccountTokenRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-managedgrafana/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
A name for the token to create.
-
#seconds_to_live ⇒ Integer
Sets how long the token will be valid, in seconds.
-
#service_account_id ⇒ String
The ID of the service account for which to create a token.
-
#workspace_id ⇒ String
The ID of the workspace the service account resides within.
Instance Attribute Details
#name ⇒ String
A name for the token to create.
534 535 536 537 538 539 540 541 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 534 class CreateWorkspaceServiceAccountTokenRequest < Struct.new( :name, :seconds_to_live, :service_account_id, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#seconds_to_live ⇒ Integer
Sets how long the token will be valid, in seconds. You can set the time up to 30 days in the future.
534 535 536 537 538 539 540 541 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 534 class CreateWorkspaceServiceAccountTokenRequest < Struct.new( :name, :seconds_to_live, :service_account_id, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#service_account_id ⇒ String
The ID of the service account for which to create a token.
534 535 536 537 538 539 540 541 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 534 class CreateWorkspaceServiceAccountTokenRequest < Struct.new( :name, :seconds_to_live, :service_account_id, :workspace_id) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace the service account resides within.
534 535 536 537 538 539 540 541 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 534 class CreateWorkspaceServiceAccountTokenRequest < Struct.new( :name, :seconds_to_live, :service_account_id, :workspace_id) SENSITIVE = [] include Aws::Structure end |