Class: Aws::ManagedGrafana::Types::DescribeWorkspaceConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ManagedGrafana::Types::DescribeWorkspaceConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-managedgrafana/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ String
The configuration string for the workspace that you requested.
-
#grafana_version ⇒ String
The supported Grafana version for the workspace.
Instance Attribute Details
#configuration ⇒ String
The configuration string for the workspace that you requested. For more information about the format and configuration options available, see Working in your Grafana workspace.
767 768 769 770 771 772 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 767 class DescribeWorkspaceConfigurationResponse < Struct.new( :configuration, :grafana_version) SENSITIVE = [] include Aws::Structure end |
#grafana_version ⇒ String
The supported Grafana version for the workspace.
767 768 769 770 771 772 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 767 class DescribeWorkspaceConfigurationResponse < Struct.new( :configuration, :grafana_version) SENSITIVE = [] include Aws::Structure end |