Class: Aws::ManagedGrafana::Types::PermissionEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::ManagedGrafana::Types::PermissionEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-managedgrafana/types.rb
Overview
A structure containing the identity of one user or group and the ‘Admin`, `Editor`, or `Viewer` role that they have.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#role ⇒ String
Specifies whether the user or group has the ‘Admin`, `Editor`, or `Viewer` role.
-
#user ⇒ Types::User
A structure with the ID of the user or group with this role.
Instance Attribute Details
#role ⇒ String
Specifies whether the user or group has the ‘Admin`, `Editor`, or `Viewer` role.
1239 1240 1241 1242 1243 1244 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1239 class PermissionEntry < Struct.new( :user, :role) SENSITIVE = [] include Aws::Structure end |
#user ⇒ Types::User
A structure with the ID of the user or group with this role.
1239 1240 1241 1242 1243 1244 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1239 class PermissionEntry < Struct.new( :user, :role) SENSITIVE = [] include Aws::Structure end |