Class: Aws::ManagedGrafana::Types::SamlConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ManagedGrafana::Types::SamlConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-managedgrafana/types.rb
Overview
A structure containing information about how this workspace works with SAML.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_organizations ⇒ Array<String>
Lists which organizations defined in the SAML assertion are allowed to use the Amazon Managed Grafana workspace.
-
#assertion_attributes ⇒ Types::AssertionAttributes
A structure that defines which attributes in the SAML assertion are to be used to define information about the users authenticated by that IdP to use the workspace.
-
#idp_metadata ⇒ Types::IdpMetadata
A structure containing the identity provider (IdP) metadata used to integrate the identity provider with this workspace.
-
#login_validity_duration ⇒ Integer
How long a sign-on session by a SAML user is valid, before the user has to sign on again.
-
#role_values ⇒ Types::RoleValues
A structure containing arrays that map group names in the SAML assertion to the Grafana ‘Admin` and `Editor` roles in the workspace.
Instance Attribute Details
#allowed_organizations ⇒ Array<String>
Lists which organizations defined in the SAML assertion are allowed to use the Amazon Managed Grafana workspace. If this is empty, all organizations in the assertion attribute have access.
1348 1349 1350 1351 1352 1353 1354 1355 1356 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1348 class SamlConfiguration < Struct.new( :idp_metadata, :assertion_attributes, :role_values, :allowed_organizations, :login_validity_duration) SENSITIVE = [] include Aws::Structure end |
#assertion_attributes ⇒ Types::AssertionAttributes
A structure that defines which attributes in the SAML assertion are to be used to define information about the users authenticated by that IdP to use the workspace.
1348 1349 1350 1351 1352 1353 1354 1355 1356 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1348 class SamlConfiguration < Struct.new( :idp_metadata, :assertion_attributes, :role_values, :allowed_organizations, :login_validity_duration) SENSITIVE = [] include Aws::Structure end |
#idp_metadata ⇒ Types::IdpMetadata
A structure containing the identity provider (IdP) metadata used to integrate the identity provider with this workspace.
1348 1349 1350 1351 1352 1353 1354 1355 1356 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1348 class SamlConfiguration < Struct.new( :idp_metadata, :assertion_attributes, :role_values, :allowed_organizations, :login_validity_duration) SENSITIVE = [] include Aws::Structure end |
#login_validity_duration ⇒ Integer
How long a sign-on session by a SAML user is valid, before the user has to sign on again.
1348 1349 1350 1351 1352 1353 1354 1355 1356 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1348 class SamlConfiguration < Struct.new( :idp_metadata, :assertion_attributes, :role_values, :allowed_organizations, :login_validity_duration) SENSITIVE = [] include Aws::Structure end |
#role_values ⇒ Types::RoleValues
A structure containing arrays that map group names in the SAML assertion to the Grafana ‘Admin` and `Editor` roles in the workspace.
1348 1349 1350 1351 1352 1353 1354 1355 1356 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1348 class SamlConfiguration < Struct.new( :idp_metadata, :assertion_attributes, :role_values, :allowed_organizations, :login_validity_duration) SENSITIVE = [] include Aws::Structure end |