Class: Aws::ManagedGrafana::Types::UpdateInstruction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-managedgrafana/types.rb

Overview

Contains the instructions for one Grafana role permission update in a

UpdatePermissions][1

operation.

[1]: docs.aws.amazon.com/grafana/latest/APIReference/API_UpdatePermissions.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

Specifies whether this update is to add or revoke role permissions.

Returns:

  • (String)


1617
1618
1619
1620
1621
1622
1623
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1617

class UpdateInstruction < Struct.new(
  :action,
  :role,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The role to add or revoke for the user or the group specified in ‘users`.

Returns:

  • (String)


1617
1618
1619
1620
1621
1622
1623
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1617

class UpdateInstruction < Struct.new(
  :action,
  :role,
  :users)
  SENSITIVE = []
  include Aws::Structure
end

#usersArray<Types::User>

A structure that specifies the user or group to add or revoke the role for.

Returns:



1617
1618
1619
1620
1621
1622
1623
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1617

class UpdateInstruction < Struct.new(
  :action,
  :role,
  :users)
  SENSITIVE = []
  include Aws::Structure
end