Class: Aws::ManagedGrafana::Types::UpdateWorkspaceConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-managedgrafana/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configurationString

The new configuration string for the workspace. For more information about the format and configuration options available, see [Working in your Grafana workspace].

[1]: docs.aws.amazon.com/grafana/latest/userguide/AMG-configure-workspace.html

Returns:

  • (String)


1731
1732
1733
1734
1735
1736
1737
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1731

class UpdateWorkspaceConfigurationRequest < Struct.new(
  :configuration,
  :workspace_id,
  :grafana_version)
  SENSITIVE = []
  include Aws::Structure
end

#grafana_versionString

Specifies the version of Grafana to support in the workspace. If not specified, keeps the current version of the workspace.

Can only be used to upgrade (for example, from 8.4 to 9.4), not downgrade (for example, from 9.4 to 8.4).

To know what versions are available to upgrade to for a specific workspace, see the [ListVersions] operation.

[1]: docs.aws.amazon.com/grafana/latest/APIReference/API_ListVersions.html

Returns:

  • (String)


1731
1732
1733
1734
1735
1736
1737
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1731

class UpdateWorkspaceConfigurationRequest < Struct.new(
  :configuration,
  :workspace_id,
  :grafana_version)
  SENSITIVE = []
  include Aws::Structure
end

#workspace_idString

The ID of the workspace to update.

Returns:

  • (String)


1731
1732
1733
1734
1735
1736
1737
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1731

class UpdateWorkspaceConfigurationRequest < Struct.new(
  :configuration,
  :workspace_id,
  :grafana_version)
  SENSITIVE = []
  include Aws::Structure
end