Class: Aws::ManagedGrafana::Types::UpdateWorkspaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ManagedGrafana::Types::UpdateWorkspaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-managedgrafana/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn]
Instance Attribute Summary collapse
-
#account_access_type ⇒ String
Specifies whether the workspace can access Amazon Web Services resources in this Amazon Web Services account only, or whether it can also access Amazon Web Services resources in other accounts in the same organization.
-
#ip_address_type ⇒ String
Specifies whether the workspace supports IPv4 only, or IPv4 and IPv6.
-
#network_access_control ⇒ Types::NetworkAccessConfiguration
The configuration settings for network access to your workspace.
-
#organization_role_name ⇒ String
The name of an IAM role that already exists to use to access resources through Organizations.
-
#permission_type ⇒ String
Use this parameter if you want to change a workspace from ‘SERVICE_MANAGED` to `CUSTOMER_MANAGED`.
-
#remove_network_access_configuration ⇒ Boolean
Whether to remove the network access configuration from the workspace.
-
#remove_vpc_configuration ⇒ Boolean
Whether to remove the VPC configuration from the workspace.
-
#stack_set_name ⇒ String
The name of the CloudFormation stack set to use to generate IAM roles to be used for this workspace.
-
#vpc_configuration ⇒ Types::VpcConfiguration
The configuration settings for an Amazon VPC that contains data sources for your Grafana workspace to connect to.
-
#workspace_data_sources ⇒ Array<String>
This parameter is for internal use only, and should not be used.
-
#workspace_description ⇒ String
A description for the workspace.
-
#workspace_id ⇒ String
The ID of the workspace to update.
-
#workspace_name ⇒ String
A new name for the workspace to update.
-
#workspace_notification_destinations ⇒ Array<String>
Specify the Amazon Web Services notification channels that you plan to use in this workspace.
-
#workspace_organizational_units ⇒ Array<String>
Specifies the organizational units that this workspace is allowed to use data sources from, if this workspace is in an account that is part of an organization.
-
#workspace_role_arn ⇒ String
Specifies an IAM role that grants permissions to Amazon Web Services resources that the workspace accesses, such as data sources and notification channels.
Instance Attribute Details
#account_access_type ⇒ String
Specifies whether the workspace can access Amazon Web Services resources in this Amazon Web Services account only, or whether it can also access Amazon Web Services resources in other accounts in the same organization. If you specify ‘ORGANIZATION`, you must specify which organizational units the workspace can access in the `workspaceOrganizationalUnits` parameter.
1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1883 class UpdateWorkspaceRequest < Struct.new( :account_access_type, :organization_role_name, :permission_type, :stack_set_name, :workspace_data_sources, :workspace_description, :workspace_id, :workspace_name, :workspace_notification_destinations, :workspace_organizational_units, :workspace_role_arn, :vpc_configuration, :remove_vpc_configuration, :network_access_control, :remove_network_access_configuration, :ip_address_type) SENSITIVE = [:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn] include Aws::Structure end |
#ip_address_type ⇒ String
Specifies whether the workspace supports IPv4 only, or IPv4 and IPv6. Valid values are ‘IPv4` and `DualStack`. For more information about IP address types, see [Network access control].
[1]: docs.aws.amazon.com/grafana/latest/userguide/AMG-configure-nac.html
1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1883 class UpdateWorkspaceRequest < Struct.new( :account_access_type, :organization_role_name, :permission_type, :stack_set_name, :workspace_data_sources, :workspace_description, :workspace_id, :workspace_name, :workspace_notification_destinations, :workspace_organizational_units, :workspace_role_arn, :vpc_configuration, :remove_vpc_configuration, :network_access_control, :remove_network_access_configuration, :ip_address_type) SENSITIVE = [:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn] include Aws::Structure end |
#network_access_control ⇒ Types::NetworkAccessConfiguration
The configuration settings for network access to your workspace.
When this is configured, only listed IP addresses and VPC endpoints will be able to access your workspace. Standard Grafana authentication and authorization will still be required.
If this is not configured, or is removed, then all IP addresses and VPC endpoints will be allowed. Standard Grafana authentication and authorization will still be required.
1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1883 class UpdateWorkspaceRequest < Struct.new( :account_access_type, :organization_role_name, :permission_type, :stack_set_name, :workspace_data_sources, :workspace_description, :workspace_id, :workspace_name, :workspace_notification_destinations, :workspace_organizational_units, :workspace_role_arn, :vpc_configuration, :remove_vpc_configuration, :network_access_control, :remove_network_access_configuration, :ip_address_type) SENSITIVE = [:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn] include Aws::Structure end |
#organization_role_name ⇒ String
The name of an IAM role that already exists to use to access resources through Organizations. This can only be used with a workspace that has the ‘permissionType` set to `CUSTOMER_MANAGED`.
1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1883 class UpdateWorkspaceRequest < Struct.new( :account_access_type, :organization_role_name, :permission_type, :stack_set_name, :workspace_data_sources, :workspace_description, :workspace_id, :workspace_name, :workspace_notification_destinations, :workspace_organizational_units, :workspace_role_arn, :vpc_configuration, :remove_vpc_configuration, :network_access_control, :remove_network_access_configuration, :ip_address_type) SENSITIVE = [:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn] include Aws::Structure end |
#permission_type ⇒ String
Use this parameter if you want to change a workspace from ‘SERVICE_MANAGED` to `CUSTOMER_MANAGED`. This allows you to manage the permissions that the workspace uses to access datasources and notification channels. If the workspace is in a member Amazon Web Services account of an organization, and that account is not a delegated administrator account, and you want the workspace to access data sources in other Amazon Web Services accounts in the organization, you must choose `CUSTOMER_MANAGED`.
If you specify this as ‘CUSTOMER_MANAGED`, you must also specify a `workspaceRoleArn` that the workspace will use for accessing Amazon Web Services resources.
For more information on the role and permissions needed, see [Amazon Managed Grafana permissions and policies for Amazon Web Services data sources and notification channels]
<note markdown=“1”> Do not use this to convert a ‘CUSTOMER_MANAGED` workspace to `SERVICE_MANAGED`. Do not include this parameter if you want to leave the workspace as `SERVICE_MANAGED`.
You can convert a `CUSTOMER_MANAGED` workspace to `SERVICE_MANAGED`
using the Amazon Managed Grafana console. For more information, see [Managing permissions for data sources and notification channels].
</note>
[1]: docs.aws.amazon.com/grafana/latest/userguide/AMG-manage-permissions.html [2]: docs.aws.amazon.com/grafana/latest/userguide/AMG-datasource-and-notification.html
1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1883 class UpdateWorkspaceRequest < Struct.new( :account_access_type, :organization_role_name, :permission_type, :stack_set_name, :workspace_data_sources, :workspace_description, :workspace_id, :workspace_name, :workspace_notification_destinations, :workspace_organizational_units, :workspace_role_arn, :vpc_configuration, :remove_vpc_configuration, :network_access_control, :remove_network_access_configuration, :ip_address_type) SENSITIVE = [:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn] include Aws::Structure end |
#remove_network_access_configuration ⇒ Boolean
Whether to remove the network access configuration from the workspace.
Setting this to ‘true` and providing a `networkAccessControl` to set will return an error.
If you remove this configuration by setting this to ‘true`, then all IP addresses and VPC endpoints will be allowed. Standard Grafana authentication and authorization will still be required.
1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1883 class UpdateWorkspaceRequest < Struct.new( :account_access_type, :organization_role_name, :permission_type, :stack_set_name, :workspace_data_sources, :workspace_description, :workspace_id, :workspace_name, :workspace_notification_destinations, :workspace_organizational_units, :workspace_role_arn, :vpc_configuration, :remove_vpc_configuration, :network_access_control, :remove_network_access_configuration, :ip_address_type) SENSITIVE = [:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn] include Aws::Structure end |
#remove_vpc_configuration ⇒ Boolean
Whether to remove the VPC configuration from the workspace.
Setting this to ‘true` and providing a `vpcConfiguration` to set will return an error.
1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1883 class UpdateWorkspaceRequest < Struct.new( :account_access_type, :organization_role_name, :permission_type, :stack_set_name, :workspace_data_sources, :workspace_description, :workspace_id, :workspace_name, :workspace_notification_destinations, :workspace_organizational_units, :workspace_role_arn, :vpc_configuration, :remove_vpc_configuration, :network_access_control, :remove_network_access_configuration, :ip_address_type) SENSITIVE = [:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn] include Aws::Structure end |
#stack_set_name ⇒ String
The name of the CloudFormation stack set to use to generate IAM roles to be used for this workspace.
1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1883 class UpdateWorkspaceRequest < Struct.new( :account_access_type, :organization_role_name, :permission_type, :stack_set_name, :workspace_data_sources, :workspace_description, :workspace_id, :workspace_name, :workspace_notification_destinations, :workspace_organizational_units, :workspace_role_arn, :vpc_configuration, :remove_vpc_configuration, :network_access_control, :remove_network_access_configuration, :ip_address_type) SENSITIVE = [:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn] include Aws::Structure end |
#vpc_configuration ⇒ Types::VpcConfiguration
The configuration settings for an Amazon VPC that contains data sources for your Grafana workspace to connect to.
1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1883 class UpdateWorkspaceRequest < Struct.new( :account_access_type, :organization_role_name, :permission_type, :stack_set_name, :workspace_data_sources, :workspace_description, :workspace_id, :workspace_name, :workspace_notification_destinations, :workspace_organizational_units, :workspace_role_arn, :vpc_configuration, :remove_vpc_configuration, :network_access_control, :remove_network_access_configuration, :ip_address_type) SENSITIVE = [:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn] include Aws::Structure end |
#workspace_data_sources ⇒ Array<String>
This parameter is for internal use only, and should not be used.
1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1883 class UpdateWorkspaceRequest < Struct.new( :account_access_type, :organization_role_name, :permission_type, :stack_set_name, :workspace_data_sources, :workspace_description, :workspace_id, :workspace_name, :workspace_notification_destinations, :workspace_organizational_units, :workspace_role_arn, :vpc_configuration, :remove_vpc_configuration, :network_access_control, :remove_network_access_configuration, :ip_address_type) SENSITIVE = [:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn] include Aws::Structure end |
#workspace_description ⇒ String
A description for the workspace. This is used only to help you identify this workspace.
1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1883 class UpdateWorkspaceRequest < Struct.new( :account_access_type, :organization_role_name, :permission_type, :stack_set_name, :workspace_data_sources, :workspace_description, :workspace_id, :workspace_name, :workspace_notification_destinations, :workspace_organizational_units, :workspace_role_arn, :vpc_configuration, :remove_vpc_configuration, :network_access_control, :remove_network_access_configuration, :ip_address_type) SENSITIVE = [:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace to update.
1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1883 class UpdateWorkspaceRequest < Struct.new( :account_access_type, :organization_role_name, :permission_type, :stack_set_name, :workspace_data_sources, :workspace_description, :workspace_id, :workspace_name, :workspace_notification_destinations, :workspace_organizational_units, :workspace_role_arn, :vpc_configuration, :remove_vpc_configuration, :network_access_control, :remove_network_access_configuration, :ip_address_type) SENSITIVE = [:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn] include Aws::Structure end |
#workspace_name ⇒ String
A new name for the workspace to update.
1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1883 class UpdateWorkspaceRequest < Struct.new( :account_access_type, :organization_role_name, :permission_type, :stack_set_name, :workspace_data_sources, :workspace_description, :workspace_id, :workspace_name, :workspace_notification_destinations, :workspace_organizational_units, :workspace_role_arn, :vpc_configuration, :remove_vpc_configuration, :network_access_control, :remove_network_access_configuration, :ip_address_type) SENSITIVE = [:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn] include Aws::Structure end |
#workspace_notification_destinations ⇒ Array<String>
Specify the Amazon Web Services notification channels that you plan to use in this workspace. Specifying these data sources here enables Amazon Managed Grafana to create IAM roles and permissions that allow Amazon Managed Grafana to use these channels.
1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1883 class UpdateWorkspaceRequest < Struct.new( :account_access_type, :organization_role_name, :permission_type, :stack_set_name, :workspace_data_sources, :workspace_description, :workspace_id, :workspace_name, :workspace_notification_destinations, :workspace_organizational_units, :workspace_role_arn, :vpc_configuration, :remove_vpc_configuration, :network_access_control, :remove_network_access_configuration, :ip_address_type) SENSITIVE = [:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn] include Aws::Structure end |
#workspace_organizational_units ⇒ Array<String>
Specifies the organizational units that this workspace is allowed to use data sources from, if this workspace is in an account that is part of an organization.
1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1883 class UpdateWorkspaceRequest < Struct.new( :account_access_type, :organization_role_name, :permission_type, :stack_set_name, :workspace_data_sources, :workspace_description, :workspace_id, :workspace_name, :workspace_notification_destinations, :workspace_organizational_units, :workspace_role_arn, :vpc_configuration, :remove_vpc_configuration, :network_access_control, :remove_network_access_configuration, :ip_address_type) SENSITIVE = [:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn] include Aws::Structure end |
#workspace_role_arn ⇒ String
Specifies an IAM role that grants permissions to Amazon Web Services resources that the workspace accesses, such as data sources and notification channels. If this workspace has ‘permissionType` `CUSTOMER_MANAGED`, then this role is required.
1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1883 class UpdateWorkspaceRequest < Struct.new( :account_access_type, :organization_role_name, :permission_type, :stack_set_name, :workspace_data_sources, :workspace_description, :workspace_id, :workspace_name, :workspace_notification_destinations, :workspace_organizational_units, :workspace_role_arn, :vpc_configuration, :remove_vpc_configuration, :network_access_control, :remove_network_access_configuration, :ip_address_type) SENSITIVE = [:organization_role_name, :workspace_description, :workspace_name, :workspace_organizational_units, :workspace_role_arn] include Aws::Structure end |