Class: Aws::ManagedGrafana::Types::ValidationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::ManagedGrafana::Types::ValidationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-managedgrafana/types.rb
Overview
The value of a parameter in the request caused an error.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_list ⇒ Array<Types::ValidationExceptionField>
A list of fields that might be associated with the error.
-
#message ⇒ String
A description of the error.
-
#reason ⇒ String
The reason that the operation failed.
Instance Attribute Details
#field_list ⇒ Array<Types::ValidationExceptionField>
A list of fields that might be associated with the error.
1954 1955 1956 1957 1958 1959 1960 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1954 class ValidationException < Struct.new( :message, :reason, :field_list) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A description of the error.
1954 1955 1956 1957 1958 1959 1960 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1954 class ValidationException < Struct.new( :message, :reason, :field_list) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The reason that the operation failed.
1954 1955 1956 1957 1958 1959 1960 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1954 class ValidationException < Struct.new( :message, :reason, :field_list) SENSITIVE = [] include Aws::Structure end |