Class: Aws::ManagedGrafana::Types::WorkspaceDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::ManagedGrafana::Types::WorkspaceDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-managedgrafana/types.rb
Overview
A structure containing information about an Amazon Managed Grafana workspace in your account.
Constant Summary collapse
- SENSITIVE =
[:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn]
Instance Attribute Summary collapse
-
#account_access_type ⇒ String
Specifies whether the workspace can access Amazon Web Services resources in this Amazon Web Services account only, or whether it can also access Amazon Web Services resources in other accounts in the same organization.
-
#authentication ⇒ Types::AuthenticationSummary
A structure that describes whether the workspace uses SAML, IAM Identity Center, or both methods for user authentication.
-
#created ⇒ Time
The date that the workspace was created.
-
#data_sources ⇒ Array<String>
Specifies the Amazon Web Services data sources that have been configured to have IAM roles and permissions created to allow Amazon Managed Grafana to read data from these sources.
-
#description ⇒ String
The user-defined description of the workspace.
-
#endpoint ⇒ String
The URL that users can use to access the Grafana console in the workspace.
-
#free_trial_consumed ⇒ Boolean
Specifies whether this workspace has already fully used its free trial for Grafana Enterprise.
-
#free_trial_expiration ⇒ Time
If this workspace is currently in the free trial period for Grafana Enterprise, this value specifies when that free trial ends.
-
#grafana_token ⇒ String
The token that ties this workspace to a Grafana Labs account.
-
#grafana_version ⇒ String
The version of Grafana supported in this workspace.
-
#id ⇒ String
The unique ID of this workspace.
-
#ip_address_type ⇒ String
The type of IP addresses supported for connection to the workspace.
-
#kms_key_id ⇒ String
The ID or ARN of the Key Management Service key used for encrypting workspace data.
-
#license_expiration ⇒ Time
If this workspace has a full Grafana Enterprise license purchased through Amazon Web Services Marketplace, this specifies when the license ends and will need to be renewed.
-
#license_type ⇒ String
Specifies whether this workspace has a full Grafana Enterprise license.
-
#modified ⇒ Time
The most recent date that the workspace was modified.
-
#name ⇒ String
The name of the workspace.
-
#network_access_control ⇒ Types::NetworkAccessConfiguration
The configuration settings for network access to your workspace.
-
#notification_destinations ⇒ Array<String>
The Amazon Web Services notification channels that Amazon Managed Grafana can automatically create IAM roles and permissions for, to allow Amazon Managed Grafana to use these channels.
-
#organization_role_name ⇒ String
The name of the IAM role that is used to access resources through Organizations.
-
#organizational_units ⇒ Array<String>
Specifies the organizational units that this workspace is allowed to use data sources from, if this workspace is in an account that is part of an organization.
-
#permission_type ⇒ String
If this is ‘SERVICE_MANAGED`, and the workplace was created through the Amazon Managed Grafana console, then Amazon Managed Grafana automatically creates the IAM roles and provisions the permissions that the workspace needs to use Amazon Web Services data sources and notification channels.
-
#stack_set_name ⇒ String
The name of the CloudFormation stack set that is used to generate IAM roles to be used for this workspace.
-
#status ⇒ String
The current status of the workspace.
-
#tags ⇒ Hash<String,String>
The list of tags associated with the workspace.
-
#vpc_configuration ⇒ Types::VpcConfiguration
The configuration for connecting to data sources in a private VPC (Amazon Virtual Private Cloud).
-
#workspace_role_arn ⇒ String
The IAM role that grants permissions to the Amazon Web Services resources that the workspace will view data from.
Instance Attribute Details
#account_access_type ⇒ String
Specifies whether the workspace can access Amazon Web Services resources in this Amazon Web Services account only, or whether it can also access Amazon Web Services resources in other accounts in the same organization. If this is ‘ORGANIZATION`, the `workspaceOrganizationalUnits` parameter specifies which organizational units the workspace can access.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#authentication ⇒ Types::AuthenticationSummary
A structure that describes whether the workspace uses SAML, IAM Identity Center, or both methods for user authentication.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#created ⇒ Time
The date that the workspace was created.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#data_sources ⇒ Array<String>
Specifies the Amazon Web Services data sources that have been configured to have IAM roles and permissions created to allow Amazon Managed Grafana to read data from these sources.
This list is only used when the workspace was created through the Amazon Web Services console, and the ‘permissionType` is `SERVICE_MANAGED`.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#description ⇒ String
The user-defined description of the workspace.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#endpoint ⇒ String
The URL that users can use to access the Grafana console in the workspace.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#free_trial_consumed ⇒ Boolean
Specifies whether this workspace has already fully used its free trial for Grafana Enterprise.
<note markdown=“1”> Amazon Managed Grafana workspaces no longer support Grafana Enterprise free trials.
</note>
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#free_trial_expiration ⇒ Time
If this workspace is currently in the free trial period for Grafana Enterprise, this value specifies when that free trial ends.
<note markdown=“1”> Amazon Managed Grafana workspaces no longer support Grafana Enterprise free trials.
</note>
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#grafana_token ⇒ String
The token that ties this workspace to a Grafana Labs account. For more information, see [Link your account with Grafana Labs].
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#grafana_version ⇒ String
The version of Grafana supported in this workspace.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#id ⇒ String
The unique ID of this workspace.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#ip_address_type ⇒ String
The type of IP addresses supported for connection to the workspace. Valid values are ‘IPv4` and `DualStack`.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#kms_key_id ⇒ String
The ID or ARN of the Key Management Service key used for encrypting workspace data.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#license_expiration ⇒ Time
If this workspace has a full Grafana Enterprise license purchased through Amazon Web Services Marketplace, this specifies when the license ends and will need to be renewed. Purchasing the Enterprise plugins option through Amazon Managed Grafana does not have an expiration. It is valid until the license is removed.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#license_type ⇒ String
Specifies whether this workspace has a full Grafana Enterprise license.
<note markdown=“1”> Amazon Managed Grafana workspaces no longer support Grafana Enterprise free trials.
</note>
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#modified ⇒ Time
The most recent date that the workspace was modified.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#name ⇒ String
The name of the workspace.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#network_access_control ⇒ Types::NetworkAccessConfiguration
The configuration settings for network access to your workspace.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#notification_destinations ⇒ Array<String>
The Amazon Web Services notification channels that Amazon Managed Grafana can automatically create IAM roles and permissions for, to allow Amazon Managed Grafana to use these channels.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#organization_role_name ⇒ String
The name of the IAM role that is used to access resources through Organizations.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#organizational_units ⇒ Array<String>
Specifies the organizational units that this workspace is allowed to use data sources from, if this workspace is in an account that is part of an organization.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#permission_type ⇒ String
If this is ‘SERVICE_MANAGED`, and the workplace was created through the Amazon Managed Grafana console, then Amazon Managed Grafana automatically creates the IAM roles and provisions the permissions that the workspace needs to use Amazon Web Services data sources and notification channels.
If this is ‘CUSTOMER_MANAGED`, you must manage those roles and permissions yourself.
If you are working with a workspace in a member account of an organization and that account is not a delegated administrator account, and you want the workspace to access data sources in other Amazon Web Services accounts in the organization, this parameter must be set to ‘CUSTOMER_MANAGED`.
For more information about converting between customer and service managed, see [Managing permissions for data sources and notification channels]. For more information about the roles and permissions that must be managed for customer managed workspaces, see [Amazon Managed Grafana permissions and policies for Amazon Web Services data sources and notification channels]
[1]: docs.aws.amazon.com/grafana/latest/userguide/AMG-datasource-and-notification.html [2]: docs.aws.amazon.com/grafana/latest/userguide/AMG-manage-permissions.html
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#stack_set_name ⇒ String
The name of the CloudFormation stack set that is used to generate IAM roles to be used for this workspace.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#status ⇒ String
The current status of the workspace.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The list of tags associated with the workspace.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#vpc_configuration ⇒ Types::VpcConfiguration
The configuration for connecting to data sources in a private VPC (Amazon Virtual Private Cloud).
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |
#workspace_role_arn ⇒ String
The IAM role that grants permissions to the Amazon Web Services resources that the workspace will view data from. This role must already exist.
2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2201 class WorkspaceDescription < Struct.new( :account_access_type, :created, :data_sources, :description, :endpoint, :grafana_version, :id, :modified, :name, :organization_role_name, :notification_destinations, :organizational_units, :permission_type, :stack_set_name, :status, :workspace_role_arn, :license_type, :free_trial_consumed, :license_expiration, :free_trial_expiration, :authentication, :tags, :vpc_configuration, :network_access_control, :grafana_token, :ip_address_type, :kms_key_id) SENSITIVE = [:description, :name, :organization_role_name, :organizational_units, :workspace_role_arn] include Aws::Structure end |