Class: Aws::ManagedGrafana::Types::WorkspaceSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-managedgrafana/types.rb

Overview

A structure that contains some information about one workspace in the account.

Constant Summary collapse

SENSITIVE =
[:description, :name]

Instance Attribute Summary collapse

Instance Attribute Details

#authenticationTypes::AuthenticationSummary

A structure containing information about the authentication methods used in the workspace.



2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2305

class WorkspaceSummary < Struct.new(
  :created,
  :description,
  :endpoint,
  :grafana_version,
  :id,
  :modified,
  :name,
  :notification_destinations,
  :status,
  :authentication,
  :tags,
  :license_type,
  :grafana_token)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#createdTime

The date that the workspace was created.

Returns:

  • (Time)


2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2305

class WorkspaceSummary < Struct.new(
  :created,
  :description,
  :endpoint,
  :grafana_version,
  :id,
  :modified,
  :name,
  :notification_destinations,
  :status,
  :authentication,
  :tags,
  :license_type,
  :grafana_token)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#descriptionString

The customer-entered description of the workspace.

Returns:

  • (String)


2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2305

class WorkspaceSummary < Struct.new(
  :created,
  :description,
  :endpoint,
  :grafana_version,
  :id,
  :modified,
  :name,
  :notification_destinations,
  :status,
  :authentication,
  :tags,
  :license_type,
  :grafana_token)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#endpointString

The URL endpoint to use to access the Grafana console in the workspace.

Returns:

  • (String)


2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2305

class WorkspaceSummary < Struct.new(
  :created,
  :description,
  :endpoint,
  :grafana_version,
  :id,
  :modified,
  :name,
  :notification_destinations,
  :status,
  :authentication,
  :tags,
  :license_type,
  :grafana_token)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#grafana_tokenString

The token that ties this workspace to a Grafana Labs account. For more information, see [Link your account with Grafana Labs].

[1]: docs.aws.amazon.com/grafana/latest/userguide/upgrade-to-Grafana-Enterprise.html#AMG-workspace-register-enterprise

Returns:

  • (String)


2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2305

class WorkspaceSummary < Struct.new(
  :created,
  :description,
  :endpoint,
  :grafana_version,
  :id,
  :modified,
  :name,
  :notification_destinations,
  :status,
  :authentication,
  :tags,
  :license_type,
  :grafana_token)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#grafana_versionString

The Grafana version that the workspace is running.

Returns:

  • (String)


2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2305

class WorkspaceSummary < Struct.new(
  :created,
  :description,
  :endpoint,
  :grafana_version,
  :id,
  :modified,
  :name,
  :notification_destinations,
  :status,
  :authentication,
  :tags,
  :license_type,
  :grafana_token)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#idString

The unique ID of the workspace.

Returns:

  • (String)


2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2305

class WorkspaceSummary < Struct.new(
  :created,
  :description,
  :endpoint,
  :grafana_version,
  :id,
  :modified,
  :name,
  :notification_destinations,
  :status,
  :authentication,
  :tags,
  :license_type,
  :grafana_token)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#license_typeString

Specifies whether this workspace has a full Grafana Enterprise license.

<note markdown=“1”> Amazon Managed Grafana workspaces no longer support Grafana Enterprise free trials.

</note>

Returns:

  • (String)


2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2305

class WorkspaceSummary < Struct.new(
  :created,
  :description,
  :endpoint,
  :grafana_version,
  :id,
  :modified,
  :name,
  :notification_destinations,
  :status,
  :authentication,
  :tags,
  :license_type,
  :grafana_token)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#modifiedTime

The most recent date that the workspace was modified.

Returns:

  • (Time)


2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2305

class WorkspaceSummary < Struct.new(
  :created,
  :description,
  :endpoint,
  :grafana_version,
  :id,
  :modified,
  :name,
  :notification_destinations,
  :status,
  :authentication,
  :tags,
  :license_type,
  :grafana_token)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#nameString

The name of the workspace.

Returns:

  • (String)


2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2305

class WorkspaceSummary < Struct.new(
  :created,
  :description,
  :endpoint,
  :grafana_version,
  :id,
  :modified,
  :name,
  :notification_destinations,
  :status,
  :authentication,
  :tags,
  :license_type,
  :grafana_token)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#notification_destinationsArray<String>

The Amazon Web Services notification channels that Amazon Managed Grafana can automatically create IAM roles and permissions for, which allows Amazon Managed Grafana to use these channels.

Returns:

  • (Array<String>)


2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2305

class WorkspaceSummary < Struct.new(
  :created,
  :description,
  :endpoint,
  :grafana_version,
  :id,
  :modified,
  :name,
  :notification_destinations,
  :status,
  :authentication,
  :tags,
  :license_type,
  :grafana_token)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#statusString

The current status of the workspace.

Returns:

  • (String)


2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2305

class WorkspaceSummary < Struct.new(
  :created,
  :description,
  :endpoint,
  :grafana_version,
  :id,
  :modified,
  :name,
  :notification_destinations,
  :status,
  :authentication,
  :tags,
  :license_type,
  :grafana_token)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#tagsHash<String,String>

The list of tags associated with the workspace.

Returns:

  • (Hash<String,String>)


2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2305

class WorkspaceSummary < Struct.new(
  :created,
  :description,
  :endpoint,
  :grafana_version,
  :id,
  :modified,
  :name,
  :notification_destinations,
  :status,
  :authentication,
  :tags,
  :license_type,
  :grafana_token)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end