Class: Aws::ManagedGrafana::Types::RoleValues
- Inherits:
-
Struct
- Object
- Struct
- Aws::ManagedGrafana::Types::RoleValues
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-managedgrafana/types.rb
Overview
This structure defines which groups defined in the SAML assertion attribute are to be mapped to the Grafana ‘Admin` and `Editor` roles in the workspace. SAML authenticated users not part of `Admin` or `Editor` role groups have `Viewer` permission over the workspace.
Constant Summary collapse
- SENSITIVE =
[:editor, :admin]
Instance Attribute Summary collapse
-
#admin ⇒ Array<String>
A list of groups from the SAML assertion attribute to grant the Grafana ‘Admin` role to.
-
#editor ⇒ Array<String>
A list of groups from the SAML assertion attribute to grant the Grafana ‘Editor` role to.
Instance Attribute Details
#admin ⇒ Array<String>
A list of groups from the SAML assertion attribute to grant the Grafana ‘Admin` role to.
1276 1277 1278 1279 1280 1281 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1276 class RoleValues < Struct.new( :editor, :admin) SENSITIVE = [:editor, :admin] include Aws::Structure end |
#editor ⇒ Array<String>
A list of groups from the SAML assertion attribute to grant the Grafana ‘Editor` role to.
1276 1277 1278 1279 1280 1281 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1276 class RoleValues < Struct.new( :editor, :admin) SENSITIVE = [:editor, :admin] include Aws::Structure end |