Class: Aws::ManagedGrafana::Types::UpdateWorkspaceConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ManagedGrafana::Types::UpdateWorkspaceConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-managedgrafana/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ String
The new configuration string for the workspace.
-
#grafana_version ⇒ String
Specifies the version of Grafana to support in the workspace.
-
#workspace_id ⇒ String
The ID of the workspace to update.
Instance Attribute Details
#configuration ⇒ String
The new configuration string for the workspace. For more information about the format and configuration options available, see [Working in your Grafana workspace].
[1]: docs.aws.amazon.com/grafana/latest/userguide/AMG-configure-workspace.html
1731 1732 1733 1734 1735 1736 1737 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1731 class UpdateWorkspaceConfigurationRequest < Struct.new( :configuration, :workspace_id, :grafana_version) SENSITIVE = [] include Aws::Structure end |
#grafana_version ⇒ String
Specifies the version of Grafana to support in the workspace. If not specified, keeps the current version of the workspace.
Can only be used to upgrade (for example, from 8.4 to 9.4), not downgrade (for example, from 9.4 to 8.4).
To know what versions are available to upgrade to for a specific workspace, see the [ListVersions] operation.
[1]: docs.aws.amazon.com/grafana/latest/APIReference/API_ListVersions.html
1731 1732 1733 1734 1735 1736 1737 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1731 class UpdateWorkspaceConfigurationRequest < Struct.new( :configuration, :workspace_id, :grafana_version) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of the workspace to update.
1731 1732 1733 1734 1735 1736 1737 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 1731 class UpdateWorkspaceConfigurationRequest < Struct.new( :configuration, :workspace_id, :grafana_version) SENSITIVE = [] include Aws::Structure end |