Class: Aws::ManagedGrafana::Types::WorkspaceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::ManagedGrafana::Types::WorkspaceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-managedgrafana/types.rb
Overview
A structure that contains some information about one workspace in the account.
Constant Summary collapse
- SENSITIVE =
[:description, :name]
Instance Attribute Summary collapse
-
#authentication ⇒ Types::AuthenticationSummary
A structure containing information about the authentication methods used in the workspace.
-
#created ⇒ Time
The date that the workspace was created.
-
#description ⇒ String
The customer-entered description of the workspace.
-
#endpoint ⇒ String
The URL endpoint to use to access the Grafana console in the workspace.
-
#grafana_token ⇒ String
The token that ties this workspace to a Grafana Labs account.
-
#grafana_version ⇒ String
The Grafana version that the workspace is running.
-
#id ⇒ String
The unique ID of the workspace.
-
#license_type ⇒ String
Specifies whether this workspace has a full Grafana Enterprise license.
-
#modified ⇒ Time
The most recent date that the workspace was modified.
-
#name ⇒ String
The name of the workspace.
-
#notification_destinations ⇒ Array<String>
The Amazon Web Services notification channels that Amazon Managed Grafana can automatically create IAM roles and permissions for, which allows Amazon Managed Grafana to use these channels.
-
#status ⇒ String
The current status of the workspace.
-
#tags ⇒ Hash<String,String>
The list of tags associated with the workspace.
Instance Attribute Details
#authentication ⇒ Types::AuthenticationSummary
A structure containing information about the authentication methods used in the workspace.
2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2277 class WorkspaceSummary < Struct.new( :created, :description, :endpoint, :grafana_version, :id, :modified, :name, :notification_destinations, :status, :authentication, :tags, :license_type, :grafana_token) SENSITIVE = [:description, :name] include Aws::Structure end |
#created ⇒ Time
The date that the workspace was created.
2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2277 class WorkspaceSummary < Struct.new( :created, :description, :endpoint, :grafana_version, :id, :modified, :name, :notification_destinations, :status, :authentication, :tags, :license_type, :grafana_token) SENSITIVE = [:description, :name] include Aws::Structure end |
#description ⇒ String
The customer-entered description of the workspace.
2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2277 class WorkspaceSummary < Struct.new( :created, :description, :endpoint, :grafana_version, :id, :modified, :name, :notification_destinations, :status, :authentication, :tags, :license_type, :grafana_token) SENSITIVE = [:description, :name] include Aws::Structure end |
#endpoint ⇒ String
The URL endpoint to use to access the Grafana console in the workspace.
2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2277 class WorkspaceSummary < Struct.new( :created, :description, :endpoint, :grafana_version, :id, :modified, :name, :notification_destinations, :status, :authentication, :tags, :license_type, :grafana_token) SENSITIVE = [:description, :name] include Aws::Structure end |
#grafana_token ⇒ String
The token that ties this workspace to a Grafana Labs account. For more information, see [Link your account with Grafana Labs].
2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2277 class WorkspaceSummary < Struct.new( :created, :description, :endpoint, :grafana_version, :id, :modified, :name, :notification_destinations, :status, :authentication, :tags, :license_type, :grafana_token) SENSITIVE = [:description, :name] include Aws::Structure end |
#grafana_version ⇒ String
The Grafana version that the workspace is running.
2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2277 class WorkspaceSummary < Struct.new( :created, :description, :endpoint, :grafana_version, :id, :modified, :name, :notification_destinations, :status, :authentication, :tags, :license_type, :grafana_token) SENSITIVE = [:description, :name] include Aws::Structure end |
#id ⇒ String
The unique ID of the workspace.
2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2277 class WorkspaceSummary < Struct.new( :created, :description, :endpoint, :grafana_version, :id, :modified, :name, :notification_destinations, :status, :authentication, :tags, :license_type, :grafana_token) SENSITIVE = [:description, :name] include Aws::Structure end |
#license_type ⇒ String
Specifies whether this workspace has a full Grafana Enterprise license.
<note markdown=“1”> Amazon Managed Grafana workspaces no longer support Grafana Enterprise free trials.
</note>
2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2277 class WorkspaceSummary < Struct.new( :created, :description, :endpoint, :grafana_version, :id, :modified, :name, :notification_destinations, :status, :authentication, :tags, :license_type, :grafana_token) SENSITIVE = [:description, :name] include Aws::Structure end |
#modified ⇒ Time
The most recent date that the workspace was modified.
2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2277 class WorkspaceSummary < Struct.new( :created, :description, :endpoint, :grafana_version, :id, :modified, :name, :notification_destinations, :status, :authentication, :tags, :license_type, :grafana_token) SENSITIVE = [:description, :name] include Aws::Structure end |
#name ⇒ String
The name of the workspace.
2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2277 class WorkspaceSummary < Struct.new( :created, :description, :endpoint, :grafana_version, :id, :modified, :name, :notification_destinations, :status, :authentication, :tags, :license_type, :grafana_token) SENSITIVE = [:description, :name] include Aws::Structure end |
#notification_destinations ⇒ Array<String>
The Amazon Web Services notification channels that Amazon Managed Grafana can automatically create IAM roles and permissions for, which allows Amazon Managed Grafana to use these channels.
2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2277 class WorkspaceSummary < Struct.new( :created, :description, :endpoint, :grafana_version, :id, :modified, :name, :notification_destinations, :status, :authentication, :tags, :license_type, :grafana_token) SENSITIVE = [:description, :name] include Aws::Structure end |
#status ⇒ String
The current status of the workspace.
2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2277 class WorkspaceSummary < Struct.new( :created, :description, :endpoint, :grafana_version, :id, :modified, :name, :notification_destinations, :status, :authentication, :tags, :license_type, :grafana_token) SENSITIVE = [:description, :name] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The list of tags associated with the workspace.
2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 |
# File 'lib/aws-sdk-managedgrafana/types.rb', line 2277 class WorkspaceSummary < Struct.new( :created, :description, :endpoint, :grafana_version, :id, :modified, :name, :notification_destinations, :status, :authentication, :tags, :license_type, :grafana_token) SENSITIVE = [:description, :name] include Aws::Structure end |